pub fn copy_closures(plan: &DeploymentPlan) -> Result<CopyResults>Expand description
Copy closures to all targets in the deployment plan.
pub fn copy_closures(plan: &DeploymentPlan) -> Result<CopyResults>Copy closures to all targets in the deployment plan.